@@ -1,27 +1,16 @@
-﻿/* GCompris - family.js
+/* GCompris - family.js
  *
- * Copyright (C) 2016 Rajdeep Kaur <rajdeep.kaur@kde.org>
+ * SPDX-FileCopyrightText: 2016 Rajdeep Kaur <rajdeep.kaur@kde.org>
  *
  * Authors:
  *
  *   Rajdeep Kaur <rajdeep.kaur@kde.org>
  *   Rudra Nil Basu <rudra.nil.basu.1996@gmail.com>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import GCompris 1.0 as GCompris
 
 .import "qrc:/gcompris/src/core/core.js" as Core
