@@ -1,27 +1,16 @@
 /* GCompris - reversecount.js
  *
- * Copyright (C) 2014 Emmanuel Charruau
+ * SPDX-FileCopyrightText: 2014 Emmanuel Charruau
  *
  * Authors:
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (GTK+ version)
  *   Emmanuel Charruau <echarruau@gmail.com> (Qt Quick port)
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (Major rework)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 
 var iceBlocksLayout = [[0, 0],[1, 0],[2, 0],[3, 0],[4, 0],
@@ -70,7 +59,8 @@ function stop() {
 
 function initLevel() {
     items.bar.level = currentLevel + 1
-    items.tuxIsMoving = false;
+    items.tuxIsMoving = false
+    items.tuxCanMove = true
     items.chooseDiceBar.value1 = 0
     items.chooseDiceBar.value2 = 0
     items.chooseDiceBar.valueMax = items.levels[currentLevel].maxNumber
@@ -89,15 +79,19 @@ function initLevel() {
 function moveTux(numberOfMovesToDo) {
     calculateTuxIceBlockNextPos(numberOfMovesToDo)
 
-    if (tuxIceBlockNumberGoal > fishIndex)
-    {
+    if(items.chooseDiceBar.value1 === 0 && items.chooseDiceBar.value2 === 0) {
+        return
+    }
+    else if (tuxIceBlockNumberGoal != fishIndex) {
         items.clockPosition--
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/darken.wav")
         if (items.clockPosition === 0) {
             lost()
             return
         }
     }
-    else if (items.chooseDiceBar.value1 != 0 || items.chooseDiceBar.value2 != 0 ) {
+    else {
+        items.tuxCanMove = false
         moveTuxToNextIceBlock()
     }
 }
@@ -177,13 +171,12 @@ function calculateTuxIceBlockNextPos(numberOfMovesToDo) {
 
 var previousFishIndex = 0
 function calculateNextPlaceFishToReach() {
-    var newFishIndex
+    var index, newFishIndex
     do {
-        newFishIndex = Math.floor(Math.random() *
-                                  (items.levels[currentLevel].maxNumber * 2 -
-                                   items.levels[currentLevel].minNumber + 1)) +
-                items.levels[currentLevel].minNumber
-    } while((previousFishIndex === newFishIndex) || (newFishIndex >= iceBlocksLayout.length))
+        index = Math.floor(Math.random() * (items.levels[currentLevel].values.length))
+        newFishIndex = items.levels[currentLevel].values[index]
+    } while(items.levels[currentLevel].values.length > 2 &&     /* Allow repetition for array size 2 */
+        ((newFishIndex === previousFishIndex) || (newFishIndex >= iceBlocksLayout.length)))
     previousFishIndex = newFishIndex
 
     fishIndex = tuxIceBlockNumber + newFishIndex
