@@ -1,26 +1,15 @@
 /* GCompris - simplepaint.js
  *
- * Copyright (C) 2014 Bruno Coudoin
+ * SPDX-FileCopyrightText: 2014 Bruno Coudoin
  *
  * Authors:
  *   Christof Petig and Ingo Konrad (GTK+ version)
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (Qt Quick port)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 
 var url = "qrc:/gcompris/src/activities/simplepaint/resource/"
 
@@ -121,7 +110,6 @@ var backgrounds = [
     'qrc:/gcompris/src/activities/fifteen/resource/background.svg'
 ]
 
-var main
 var items
 
 // The size of the array
@@ -133,9 +121,8 @@ var numberOfLevel = backgrounds.length
 
 var background
 
-function start(main_, items_, _background) {
+function start(items_, _background) {
     background=_background
-    main = main_
     items = items_
     currentLevel = 0
     initLevel()
@@ -151,7 +138,7 @@ function initLevel() {
     items.selectedColor = items.colors[1]
     items.colorSelector.positionViewAtBeginning()
     nbx = 20 + currentLevel
-    nby = Math.floor(nbx * (main.height / main.width))
+    nby = Math.floor(nbx * (items.gridLayout.height / items.gridLayout.width))
     background.refreshCursor()
 
     var model = []
